@@ -1,3 +1,5 @@
+import sys
+import platform
 import urllib
 import urllib2
 import httplib
@@ -11,7 +13,7 @@ except ImportError:
   import simplejson as json
 from utils import json_to_py, get_faker
 
-__version_info__ = ('3', '1', '0')
+__version_info__ = ('3', '2', '0')
 __version__ = '.'.join(__version_info__)
 
 class CreateSendError(Exception):
@@ -118,7 +120,7 @@ class CreateSendBase(object):
   def make_request(self, method, path, params={}, body="", username=None,
     password=None, base_uri=None, content_type=None):
     headers = {
-      'User-Agent': 'createsend-python-%s' % __version__,
+      'User-Agent': CreateSend.user_agent,
       'Content-Type': 'application/json; charset=utf-8',
       'Accept-Encoding' : 'gzip, deflate' }
     if content_type:
@@ -204,6 +206,13 @@ class CreateSend(CreateSendBase):
   base_uri = "https://api.createsend.com/api/v3"
   oauth_uri = "https://api.createsend.com/oauth"
   oauth_token_uri = "%s/token" % oauth_uri
+  default_user_agent = 'createsend-python-%s-%d.%d.%d-%s' % (
+    __version__, sys.version_info[0], sys.version_info[1],
+    sys.version_info[2], platform.platform())
+  # You can use `CreateSend.user_agent = "my user agent"` to override the
+  # default user agent string (CreateSend.default_user_agent) used when
+  # making API calls.
+  user_agent = default_user_agent
 
   def __init__(self, auth=None):
     super(CreateSend, self).__init__(auth)
